pub fn read_file_list(source: &str) -> Result<Vec<PathBuf>>Expand description
Read newline-separated file paths from a file or stdin (when source is
"-"). Empty lines are skipped.
Errors
Returns an error if the file cannot be read or stdin cannot be consumed.